@@ -20,7 +20,8 @@
 #ifndef CANVAS_H
 #define CANVAS_H
 
-typedef enum { CANVAS_GROUP_POLYGONS=0, CANVAS_GROUP_TRACK, CANVAS_GROUP_GPS, 
+typedef enum { CANVAS_GROUP_BG=0, CANVAS_GROUP_POLYGONS, 
+	       CANVAS_GROUP_TRACK, CANVAS_GROUP_GPS, 
 	       CANVAS_GROUP_WAYS_HL, CANVAS_GROUP_WAYS_OL, 
 	       CANVAS_GROUP_WAYS, CANVAS_GROUP_NODES_HL, CANVAS_GROUP_NODES, 
 	       CANVAS_GROUP_DRAW, CANVAS_GROUPS } canvas_group_t;
@@ -101,4 +102,8 @@ void canvas_scroll_to(canvas_t *canvas, gint sx, gint sy);
 void canvas_set_bounds(canvas_t *canvas, gint minx, gint miny, 
 		       gint maxx, gint maxy);
 
+canvas_item_t *canvas_image_new(struct map_s *map, canvas_group_t group,
+				GdkPixbuf *pix, gint x, gint y, 
+				float hscale, float vscale);
+
 #endif // CANVAS_H
