@@ -20,8 +20,8 @@
 #ifndef DIFF_H
 #define DIFF_H
 
-void diff_save(project_t *project, gpx_t *gpx);
-void diff_restore(appdata_t *appdata, project_t *project, gpx_t *gpx);
+void diff_save(project_t *project, osm_t *osm);
+void diff_restore(appdata_t *appdata, project_t *project, osm_t *osm);
 gboolean diff_present(project_t *project);
 void diff_remove(project_t *project);
 
