@@ -105,6 +105,18 @@ cb_menu_upload(GtkWidget *window, gpointer data) {
   osm_upload(appdata, appdata->osm, appdata->project);
 }
 
+static void 
+cb_menu_wms_import(GtkWidget *window, gpointer data) {
+  appdata_t *appdata = (appdata_t*)data;
+  wms_import(appdata);
+}
+
+static void 
+cb_menu_wms_clear(GtkWidget *window, gpointer data) {
+  appdata_t *appdata = (appdata_t*)data;
+  wms_remove(appdata);
+}
+
 #if 1
 static void 
 cb_menu_redraw(GtkWidget *window, gpointer data) {
@@ -202,13 +214,14 @@ cb_menu_track_gps(GtkWidget *window, gpointer data) {
 
 static void 
 cb_menu_track_export(GtkWidget *window, gpointer data) {
-  //  appdata_t *appdata = (appdata_t*)data;
+  appdata_t *appdata = (appdata_t*)data;
+  messagef(GTK_WIDGET(appdata->window), _("NIY"),
+	   _("Track export is not yet supported."));
 }
 
 static void 
 cb_menu_track_clear(GtkWidget *window, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
-
   track_do(appdata, TRACK_NONE, NULL);
 }
 
@@ -239,6 +252,24 @@ void menu_create(appdata_t *appdata) {
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_redraw), appdata);
 #endif
 
+  /* -------------------- wms submenu -------------------- */
+
+  item = gtk_menu_item_new_with_label( _("WMS") );
+  gtk_menu_append(GTK_MENU_SHELL(menu), item);
+  submenu = gtk_menu_new();
+  gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
+  
+  item = gtk_menu_item_new_with_label( _("Import...") );
+  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_wms_import), 
+		   appdata);
+
+  item = gtk_menu_item_new_with_label( _("Clear...") );
+  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_wms_clear), 
+		   appdata);
+
+
   /* -------------------- track submenu -------------------- */
 
   item = gtk_menu_item_new_with_label( _("Track") );
@@ -316,6 +347,8 @@ void cleanup(appdata_t *appdata) {
   while(gtk_events_pending())
     gtk_main_iteration();
 
+  map_remove_bg_image(appdata->map);
+
   osm_free(appdata->osm);
 
   curl_global_cleanup();
@@ -482,6 +515,8 @@ int main(int argc, char *argv[]) {
   if(appdata.track.track)
     map_track_draw(appdata.map, appdata.track.track);
 
+  wms_load(&appdata);
+
   /* ------------ jump into main loop ---------------- */
 
   gtk_main();
