@@ -1338,3 +1338,48 @@ void map_track_pos(appdata_t *appdata, lpos_t *lpos) {
     appdata->track.gps_item = canvas_circle_new(appdata->map, CANVAS_GROUP_GPS, 
 	lpos->x, lpos->y, 1.5 * WAY_WIDTH, 0, TRACK_GPS_COLOR, NO_COLOR);
 }
+
+/* ------------------- map background ------------------ */
+
+void map_remove_bg_image(map_t *map) {
+  if(!map) return;
+
+  if(map->bg_item) {
+    canvas_item_destroy(map->bg_item);
+    map->bg_item = NULL;
+  }
+}
+
+static gint map_bg_item_destroy_event(GtkWidget *widget, gpointer data) {
+  map_t *map = (map_t*)data;
+
+  /* destroying background item */
+
+  map->bg_item = NULL;
+  if(map->bg_pix) {
+    printf("destroying background item\n");
+    gdk_pixbuf_unref(map->bg_pix);
+    map->bg_pix = NULL;
+  }
+  return FALSE;
+}
+
+void map_set_bg_image(map_t *map, char *filename) {
+  bounds_t *bounds = map->appdata->osm->bounds;
+
+  map_remove_bg_image(map);
+
+  map->bg_pix = gdk_pixbuf_new_from_file(filename, NULL);
+
+  float hscale = (float)(bounds->max.x - bounds->min.x)/
+    (float)gdk_pixbuf_get_width(map->bg_pix);
+
+  float vscale = (float)(bounds->max.y - bounds->min.y)/
+    (float)gdk_pixbuf_get_height(map->bg_pix);
+
+  map->bg_item = canvas_image_new(map, CANVAS_GROUP_BG, map->bg_pix, 
+			  bounds->min.x, bounds->min.y, hscale, vscale);
+
+  canvas_item_destroy_connect(map->bg_item, 
+          G_CALLBACK(map_bg_item_destroy_event), map);
+}  
