@@ -91,6 +91,9 @@ typedef struct map_s {
   canvas_item_t *cursor;           // the cursor visible on the draw layer
   canvas_item_t *touchnode;        // the blue "touch node" on the draw layer
 
+  GdkPixbuf *bg_pix;
+  canvas_item_t *bg_item;
+
   map_action_t action;             // current action in progress
 
   /* variables required for pen/mouse handling */
@@ -104,6 +107,7 @@ typedef struct map_s {
                                 // (may be part of a selected way)
   } pen_down;
 
+
 } map_t;
 
 GtkWidget *map_new(appdata_t *appdata);
@@ -131,4 +135,8 @@ void map_track_update_seg(map_t *map, struct track_seg_s *seg);
 void map_track_remove(appdata_t *appdata);
 void map_track_pos(appdata_t *appdata, lpos_t *lpos);
 
+/* background stuff */
+void map_set_bg_image(map_t *map, char *filename);
+void map_remove_bg_image(map_t *map);
+
 #endif // MAP_H
