@@ -1131,9 +1131,27 @@ relation_chain_t *osm_node_to_relation(osm_t *osm, node_t *node) {
 
     member_t *member = relation->member;
     while(member) {
-      if((member->type == NODE) && (member->node == node))
-	is_member = TRUE;
+      switch(member->type) {
+      case NODE:
+	/* nodes are checked directly */
+	if(member->node == node)
+	  is_member = TRUE;
+	break;
 
+      case WAY: {
+	/* ways have to be checked for the nodes they consist of */
+	node_chain_t *chain = member->way->node_chain;
+	while(chain && !is_member) {
+	  if(chain->node == node)
+	    is_member = TRUE;
+
+	  chain = chain->next;
+	}
+      } break;
+
+      default:
+	break;
+      }
       member = member->next;
     }
 
