@@ -74,7 +74,7 @@ typedef struct {
 typedef struct {
   appdata_t *appdata;
   GtkWidget *dialog;
-  gpx_t *gpx;
+  osm_t *osm;
   project_t *project;
 
   struct log_s {
@@ -440,14 +440,14 @@ static GtkWidget *table_attach_int(GtkWidget *table, int num,
 }
 
 static void osm_upload_nodes(osm_upload_context_t *context) {
-  node_t *node = context->gpx->node;
+  node_t *node = context->osm->node;
   project_t *project = context->project;
 
   while(node) {
     /* make sure gui gets updated */
     while(gtk_events_pending()) gtk_main_iteration();
 
-    if(node->flags & GPX_FLAG_DELETED) {
+    if(node->flags & OSM_FLAG_DELETED) {
       printf("deleting node on server\n");
 
       appendf(&context->log, _("Delete node #%ld "), node->id);
@@ -456,17 +456,17 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
       char *cred = g_strdup_printf("%s:%s", project->username, project->password);
 
       if(osm_delete_item(&context->log, url, cred)) {
-	node->flags &= ~(GPX_FLAG_DIRTY | GPX_FLAG_DELETED);
+	node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
 	project->dirty = TRUE;
       }
       
       g_free(cred);
     }
     
-    if(node->flags & (GPX_FLAG_DIRTY | GPX_FLAG_NEW)) {
+    if(node->flags & (OSM_FLAG_DIRTY | OSM_FLAG_NEW)) {
       char *url = NULL;
 
-      if(node->flags & GPX_FLAG_NEW) {
+      if(node->flags & OSM_FLAG_NEW) {
 	url = g_strdup_printf("%s/node/create", project->server);
 	appendf(&context->log, _("New node "));
       } else {
@@ -475,16 +475,16 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
       }
 
       /* upload this node */
-      char *xml_str = gpx_generate_xml_node(context->gpx, node);
+      char *xml_str = osm_generate_xml_node(context->osm, node);
       if(xml_str) {
 	printf("uploading node %s from address %p\n", url, xml_str);
 
 	char *cred = g_strdup_printf("%s:%s", 
 				     project->username, project->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
-			   (node->flags & GPX_FLAG_NEW)?&(node->id):NULL)) {
+			   (node->flags & OSM_FLAG_NEW)?&(node->id):NULL)) {
 
-	  node->flags &= ~(GPX_FLAG_DIRTY | GPX_FLAG_NEW);
+	  node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
 	  project->dirty = TRUE;
 	}
 
@@ -501,27 +501,27 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
 }
 
 static void osm_upload_ways(osm_upload_context_t *context) {
-  way_t *way = context->gpx->way;
+  way_t *way = context->osm->way;
   project_t *project = context->project;
 
   while(way) {
     /* make sure gui gets updated */
     while(gtk_events_pending()) gtk_main_iteration();
     
-    if(way->flags & GPX_FLAG_DIRTY) {
+    if(way->flags & OSM_FLAG_DIRTY) {
       char *url = g_strdup_printf("%s/way/%lu", project->server, way->id);
 
       appendf(&context->log, _("Modified way #%ld "), way->id);
 
       /* upload this node */
-      char *xml_str = gpx_generate_xml_way(context->gpx, way);
+      char *xml_str = osm_generate_xml_way(context->osm, way);
       if(xml_str) {
 	printf("uploading way %s from address %p\n", url, xml_str);
 
 	char *cred = g_strdup_printf("%s:%s", 
 		     project->username, project->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, NULL)) {
-	  way->flags &= ~GPX_FLAG_DIRTY;
+	  way->flags &= ~OSM_FLAG_DIRTY;
 	  project->dirty = TRUE;
 	}
 
@@ -536,7 +536,7 @@ static void osm_upload_ways(osm_upload_context_t *context) {
 }
 
 
-void osm_upload(appdata_t *appdata, gpx_t *gpx, project_t *project) {
+void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
 
   printf("starting upload\n");
 
@@ -546,12 +546,12 @@ void osm_upload(appdata_t *appdata, gpx_t *gpx, project_t *project) {
   osm_dirty_t dirty;
   memset(&dirty, 0, sizeof(osm_dirty_t));
 
-  node_t *node = gpx->node;
+  node_t *node = osm->node;
   while(node) {
     dirty.nodes.total++;
-    if(node->flags & GPX_FLAG_DELETED)     dirty.nodes.deleted++;
-    else if(node->flags & GPX_FLAG_NEW)    dirty.nodes.new++;
-    else if(node->flags & GPX_FLAG_DIRTY)  dirty.nodes.dirty++;
+    if(node->flags & OSM_FLAG_DELETED)     dirty.nodes.deleted++;
+    else if(node->flags & OSM_FLAG_NEW)    dirty.nodes.new++;
+    else if(node->flags & OSM_FLAG_DIRTY)  dirty.nodes.dirty++;
 
     node = node->next;
   }
@@ -559,12 +559,12 @@ void osm_upload(appdata_t *appdata, gpx_t *gpx, project_t *project) {
 	 dirty.nodes.new, dirty.nodes.dirty, dirty.nodes.deleted);
   
   /* count ways */
-  way_t *way = gpx->way;
+  way_t *way = osm->way;
   while(way) {
     dirty.ways.total++;
-    if(way->flags & GPX_FLAG_DELETED)      dirty.ways.deleted++;
-    else if(way->flags & GPX_FLAG_NEW)     dirty.ways.new++;
-    else if(way->flags & GPX_FLAG_DIRTY)   dirty.ways.dirty++;
+    if(way->flags & OSM_FLAG_DELETED)      dirty.ways.deleted++;
+    else if(way->flags & OSM_FLAG_NEW)     dirty.ways.new++;
+    else if(way->flags & OSM_FLAG_DIRTY)   dirty.ways.dirty++;
 
     way = way->next;
   }
@@ -572,12 +572,12 @@ void osm_upload(appdata_t *appdata, gpx_t *gpx, project_t *project) {
 	 dirty.ways.new, dirty.ways.dirty, dirty.ways.deleted);
 
   /* count relations */
-  relation_t *relation = gpx->relation;
+  relation_t *relation = osm->relation;
   while(relation) {
     dirty.relations.total++;
-    if(relation->flags & GPX_FLAG_DELETED)      dirty.relations.deleted++;
-    else if(relation->flags & GPX_FLAG_NEW)     dirty.relations.new++;
-    else if(relation->flags & GPX_FLAG_DIRTY)   dirty.relations.dirty++;
+    if(relation->flags & OSM_FLAG_DELETED)      dirty.relations.deleted++;
+    else if(relation->flags & OSM_FLAG_NEW)     dirty.relations.new++;
+    else if(relation->flags & OSM_FLAG_DIRTY)   dirty.relations.dirty++;
 
     relation = relation->next;
   }
@@ -658,7 +658,7 @@ void osm_upload(appdata_t *appdata, gpx_t *gpx, project_t *project) {
   /* osm upload itself also has a gui */
   osm_upload_context_t *context = g_new0(osm_upload_context_t, 1);
   context->appdata = appdata;
-  context->gpx = gpx;
+  context->osm = osm;
   context->project = project;
 
   context->dialog = gtk_dialog_new_with_buttons(_("Upload to OSM"),
@@ -732,16 +732,21 @@ void osm_upload(appdata_t *appdata, gpx_t *gpx, project_t *project) {
       
       /* redraw the entire map by destroying all map items and redrawing them */
       appendf(&context->log, _("Cleaning up ...\n"));
-      diff_save(appdata->project, appdata->gpx);
+      track_save(appdata->project, appdata->track.track);
+      diff_save(appdata->project, appdata->osm);
       map_clear(appdata);
-      gpx_free(appdata->gpx);
+      osm_free(appdata->osm);
       
       appendf(&context->log, _("Loading OSM ...\n"));
-      appdata->gpx = gpx_parse(appdata->project->osm);
+      appdata->osm = osm_parse(appdata->project->osm);
       appendf(&context->log, _("Applying diff ...\n"));
-      diff_restore(appdata, appdata->project, appdata->gpx);
+      diff_restore(appdata, appdata->project, appdata->osm);
       appendf(&context->log, _("Painting ...\n"));
       map_paint(appdata);
+      appendf(&context->log, _("Restoring track ...\n"));
+      appdata->track.track = track_restore(appdata, appdata->project);
+      if(appdata->track.track)
+	map_track_draw(appdata->map, appdata->track.track);
       appendf(&context->log, _("Done!\n"));
     }
   }
