@@ -24,66 +24,21 @@
 #define TAG_STATE  GTK_STATE_PRELIGHT
 
 void pos_lat_str(char *str, int len, float latitude) {
-  char *c = _("N");
-  float integral, fractional;
-
-  if(latitude < 0) { latitude = fabs(latitude); c = _("S"); }
-  fractional = modff(latitude, &integral);
-
-  snprintf(str, len, "%s %02d° %06.3f'", c, (int)integral, fractional*60.0);
+  if(len > 10) len = 10;
+  g_ascii_dtostr(str, len, latitude);
 }
 
 void pos_lon_str(char *str, int len, float longitude) {
-  char *c = _("E");
-  float integral, fractional;
-
-  if(longitude < 0) { longitude = fabs(longitude); c = _("W"); }
-  fractional = modff(longitude, &integral);
-
-  snprintf(str, len, "%s %03d° %06.3f'", c, (int)integral, fractional*60.0);
+  if(len > 10) len = 10;
+  g_ascii_dtostr(str, len, longitude);
 }
 
 float pos_parse_lat(char *str) {
-  int integral_int;
-  float fractional;
-  char c;
-
-  if(sscanf(str, "%c %d° %f'", &c, &integral_int, &fractional) == 3) {
-    c = toupper(c);
-
-    if(c != 'S' && c != 'N')
-      return NAN;
-
-    /* prevent -0.0 */
-    if(!integral_int && (fractional == 0.0))
-      return 0.0;
-
-    return ((c == 'S')?-1:+1) * (integral_int + fractional/60.0);
-  }
-
-  return NAN;
+  return g_ascii_strtod(str, NULL);
 }
 
 float pos_parse_lon(char *str) {
-  int integral_int;
-  float fractional;
-  char c;
-
-  if(sscanf(str, "%c %d° %f'", &c, &integral_int, &fractional) == 3) {
-    c = toupper(c);
-
-    /* O is german "Ost" for "East" */
-    if(c != 'E' && c != 'W' && c != 'O')
-      return NAN;
-
-    /* prevent -0.0 */
-    if(!integral_int && (fractional == 0.0))
-      return 0.0;
-
-    return ((c == 'W')?-1:+1) * (integral_int + fractional/60.0);
-  }
-
-  return NAN;
+  return g_ascii_strtod(str, NULL);
 }
 
 static gboolean mark(GtkWidget *widget, gboolean valid) {
