@@ -26,14 +26,27 @@
 #define NAN (0.0/0.0)
 #endif
 
+/* equatorial radius in meters */
+#define POS_EQ_RADIUS     (6378137.0)
+
+#define DEG2RAD(a)  ((a) * M_PI / 180.0)
+#define RAD2DEG(a)  ((a) * 180.0 / M_PI)
+
+/* global position */
 typedef struct pos {
   float lat, lon;
 } pos_t;
 
+/* local position */
 typedef struct lpos {
   gint x, y;
 } lpos_t;
 
+struct bounds_s;
+void pos2lpos(struct bounds_s *bounds, pos_t *pos, lpos_t *lpos);
+void pos2lpos_center(pos_t *pos, lpos_t *lpos);
+void lpos2pos(struct bounds_s *bounds, lpos_t *lpos, pos_t *pos);
+
 void pos_lat_str(char *str, int len, float latitude);
 void pos_lon_str(char *str, int len, float longitude);
 float pos_parse_lat(char *str);
