@@ -31,6 +31,9 @@ typedef struct project_s {
   char *username;
   char *password;
 
+  char *wms_server;
+  char *wms_path;
+
   pos_t min, max;
 
   gboolean dirty;   /* needs to download new data */
